from __future__ import print_function
import os
import datetime


def AppendRawDataFiles(OutRunNo=990000, outDataPath="-", RunNo1=0, RunNo2=0, RunNo3=0, RunNo4=0, RunNo5=0, RunNo6=0):
    """
    append several EventData iles into one

    @param OutRunNo (int) output run number
    @param outDataPath (string) output data path (default is empty)
    @param RunNo1   (int) run number 1
    @param RunNo2   (int) run number 2
    @param RunNo3   (int) run number 3
    @param RunNo4   (int) run number 4
    @param RunNo5   (int) run number 5
    @param RunNo6   (int) run number 6
    @retval None
    """
    RunNoList = []
    if RunNo1 > 0:
        RunNoList.append(RunNo1)
    if RunNo2 > 0:
        RunNoList.append(RunNo2)
    if RunNo3 > 0:
        RunNoList.append(RunNo3)
    if RunNo4 > 0:
        RunNoList.append(RunNo4)
    if RunNo5 > 0:
        RunNoList.append(RunNo5)
    if RunNo6 > 0:
        RunNoList.append(RunNo6)

    if len(RunNoList) == 0:
        raise UserWarning("No run number was set.")

    mlf_DataPath = os.path.join(
        os.environ["UTSUSEMI_DATA_DIR"], os.environ["UTSUSEMI_INST_CODE"])

    if outDataPath == "-":
        outDataPath = mlf_DataPath
    if not os.path.exists(outDataPath):
        raise UserWarning("No Data path=%" % (outDataPath))

    existed_Dirs = os.listdir(mlf_DataPath)
    existed_Dirs.sort()
    target_Dirs = []
    inst_code = ""

    # find directory such a XXXnnnnnn_yyyymmdd
    for i in range(len(existed_Dirs)):
        a_dir = existed_Dirs[i]

        if len(a_dir) != 18 or a_dir[9] != "_":
            continue
        else:
            inst_code = a_dir[:3]

            if int(a_dir[3:9]) in RunNoList:
                target_Dirs.append(os.path.join(mlf_DataPath, a_dir))

            if int(a_dir[3:9]) == OutRunNo:
                raise UserWarning(
                    "OutRunNo(%06d) already exists." % (OutRunNo))

    if len(target_Dirs) == 0:
        raise UserWarning(
            " There is no data of given run numbers in %s" % (mlf_DataPath))

    # copy files in first directory
    efiles = os.listdir(target_Dirs[0])
    id_dic = {}
    from_Dirs = {}
    print(target_Dirs[0][-15:-9])

    for target_dir in target_Dirs:
        efiles = os.listdir(target_dir)
        # [-15:-9]=nnnnnn runNo
        from_Dirs[int(target_dir[-15:-9])] = target_dir

        for efile in efiles:
            # XXXnnnnnn_DD_MMM_NNN.edb
            if (efile[-3:] == "edb"):
                key = efile[10:16]        # DD_MMM
                run_no = int(efile[3:9])  # nnnnnn
                if key in id_dic:
                    if not (run_no in id_dic[key]):
                        id_dic[key].append(run_no)
                else:
                    id_dic[key] = [run_no]

    """
    for key in id_dic.keys():
        print "id_dic=",key,id_dic[key]

    for key in from_Dirs.keys():
        print "from_Dirs=",key,from_Dirs[key]



    id_dic2 = {}

    for key in id_dic.keys():
        if len( id_dic[key] )==len( RunNoList ):
            id_dic2[ key ] = id_dic[key]
    """

    id_dic2 = id_dic
    if outDataPath != mlf_DataPath:
        com = "mkdir -p %s" % (outDataPath)
        print(com)
        os.system(com)

    datenow = datetime.datetime.now()

    outDir = os.path.join(outDataPath, "%s%06d_%4d%02d%02d" % (
        inst_code, OutRunNo, datenow.year, datenow.month, datenow.day))
    com = "mkdir -p %s" % (outDir)
    print(com)
    os.system(com)

    for key in id_dic2:
        print("DAQ_Module=", key)
        id_dic2[key].sort()
        for i in range(len(id_dic2[key])):
            run_no = id_dic2[key][i]
            # print "run_no=",run_no
            ind = 0
            while(True):
                from_file = "%3s%06d_%s_%03d.edb" % (
                    inst_code, run_no, key, ind)
                to_file = "%3s%06d_%s_%03d.edb" % (inst_code, OutRunNo, key, 0)
                fullpath_from_file = os.path.join(from_Dirs[run_no], from_file)
                if os.path.exists(fullpath_from_file):
                    com = "cat %s >> %s" % (
                        fullpath_from_file, os.path.join(outDir, to_file))
                    print(com)
                    os.system(com)

                    ind += 1
                else:
                    break



#!/usr/bin/python
# -*- coding: utf-8 -*-
import os,sys,time
ver = float(sys.version_info[0])+float(sys.version_info[1])*0.1
if ver<2.5:
    from elementtree.ElementTree import ElementTree,fromstring,XML,tostring
else:
    from xml.etree.ElementTree import ElementTree,fromstring,XML,tostring

from numpy import *
import time

import Manyo.Utsusemi as mm
##import vis.VisualContCommon as VCC

#######################################
#  SampleInfo
#######################################  
class SampleInfo(object):
    """
     サンプルデータクラス
    """
    #########################################
    def __init__(self, runno=None):
        """
        コンストラクタ
        @param  runno  サンプル名=ラン番号　 
        @retval 無し
        """         
        # サンプル情報
        self.a = 1.0
        self.b = 1.0
        self.c = 1.0
        self.alpha = 90.0
        self.beta = 90.0
        self.gamma = 90.0
        self.uh = 0.0
        self.uk = 0.0
        self.ul = 1.0
        self.vh = 0.0
        self.vk = 1.0
        self.vl = 0.0
        self.fai = 0.0
        self.rotSteps = []
        # ラン番号が指定されていれば
        if runno != None:
            # サンプル情報を取得
            self._RetrieveInfo(runno)

    #########################################
    def _RetrieveInfo(self, runno):
        """
        ラン番号からサンプル情報を検索し
        データに設定
        @param  runno  サンプル名=ラン番号　 
        @retval 無し
        """             
        # パラメータディレクトリを取得
        path = UtilPlot.AcqPath().GetPrmPath()
        # パラメータファイル名(Run No. + xml)
        fpath = os.path.join(path, runno + '.xml')
        # ファイルがあるか            
        if os.path.isfile(fpath):
            # ファイルを開く
            try:
                fp =open(fpath, 'r')
                pelm = EU.ReadElement(fp)
                # メソッドのノードを取得
                mth = pelm.find(DTAG_METHOD)
            except:
                return
            # メソッドタグを取得できたか
            if mth == None:
                return
            # 回転角を取得
            gonio = mth.find(DEV_INSTNAME_GONIO)
            if gonio != None:
                prms = gonio.find(DTAG_PARAMS)
                fai = prms.find(DTAG_PSI)
                # 回転角を取得できたなら
                if fai != None:
                    try:
                        self.fai = float(fai.text)
                    except:
                        pass
            # アシスタントのタグを取得
            assist = mth.find(DTAG_ASSISTANT)
            if assist == None:
                return
            # 格子情報を取得
            lattice = assist.find(DTAG_LATTICE)
            if lattice == None:
                return
            try:
                a = lattice.find(DTAG_A)
                if a != None:
                    self.a = float(a.text)
                b = lattice.find(DTAG_B)
                if b != None:
                    self.b = float(b.text)   
                c = lattice.find(DTAG_C)
                if c != None:
                    self.c = float(c.text)
                    
                alpha = lattice.find(DTAG_ALPHA)
                if alpha != None:
                    self.alpha = float(alpha.text)
                beta = lattice.find(DTAG_BETA)
                if beta != None:
                    self.beta = float(beta.text)   
                gamma = lattice.find(DTAG_GAMMA)
                if gamma != None:
                    self.gamma = float(gamma.text)    
            except:
                return
            # 平面情報を取得
            plane = assist.find(DTAG_PLANE)
            if plane == None:
                return
            try:
                uh = plane.find(DTAG_UH)
                if uh != None:
                    self.uh = float(uh.text)
                ul = plane.find(DTAG_UL)
                if ul != None:
                    self.ul = float(ul.text)
                uk = plane.find(DTAG_UK)
                if uk != None:
                    self.uk = float(uk.text)
                vh = plane.find(DTAG_VH)
                if vh != None:
                    self.vh = float(vh.text)
                vl = plane.find(DTAG_VL)
                if vl != None:
                    self.vl = float(vl.text)
                vk = plane.find(DTAG_VK)
                if vk != None:
                    self.vk = float(vk.text)
            except:
                pass                        

    #[inamura 110206]-->
    #############################################
    def SetInfoFromHeader(self, mh=None):
        """
        """
        if type(mh)!=type(Manyo.HeaderBase()):
            raise
        try:
            if mh.CheckKey("SampleLatticeConst")!=0:
                slc = mh.PutDoubleVector("SampleLatticeConst")
                self.a = slc[0]
                self.b = slc[1]
                self.c = slc[2]
            if mh.CheckKey("SampleLatticeAngle")!=0:
                sla = mh.PutDoubleVector("SampleLatticeAngle")
                self.alpha = sla[0]
                self.beta = sla[1]
                self.gamma = sla[2]
            if mh.CheckKey("SampleUvec")!=0:
                suv = mh.PutDoubleVector("SampleUvec")
                self.uh = suv[0]
                self.uk = suv[1]
                self.ul = suv[2]
            if mh.CheckKey("SampleVvec")!=0:
                svv = mh.PutDoubleVector("SampleVvec")
                self.vh = svv[0]
                self.vk = svv[1]
                self.vl = svv[2]
            if mh.CheckKey("SampleRotateAngle")!=0:
                sra = mh.PutDoubleVector("SampleRotateAngle")
                self.fai = sra[0]
            ##[inamura 160621]-->
            if mh.CheckKey("SampleRotateSteps")!=0:
                rts = mh.PutDoubleVector("SampleRotateSteps")
                self.rotSteps = []
                for i in range( rts.size() ):
                    if i%2==0:
                        if rts[i]==0.0:
                            self.rotSteps.append( ["X",float(rts[i+1]) ] )
                        elif rts[i]==1.0:
                            self.rotSteps.append( ["Y",float(rts[i+1]) ] )
                        elif rts[i]==2.0:
                            self.rotSteps.append( ["Z",float(rts[i+1]) ] )
                        else:
                            raise UserWarning, "SampleRotateSteps in Header is invalid."
                            self.rotSteps=[]
            ##<--[inamura 160621]
        except:
            pass
        
################################
#      VisCont parameter
################################
class VisContParams(object):
    """
    Treating parameter file for VisCont seriese
    ver 0.3 [Inamura 101125]
    
    """
    __version__="0.3"

    #####################################
    def __init__(self,filepath=""):
        """
        Constructor
        @param filepath (string) path/to/xmlfile
        @return None
        """
        
        self.filepath = filepath
        self.root_ele = None        
        self.smpInfo  = None
        
        self.paxis_info = None
        self.proj_axes = None
        
        self.type_dic={"x":0,"y":0,"p":0,"t":0}
        self.folding  = [0,0,0,0]
        
        self.EnableVisType=None

        self.CommentHead = "VisContParams >> "

        if self.filepath!="":
            try:
                self.SetParamFile( self.filepath )
                self.LoadVisualContParams()
            except:
                print self.CommentHead
                pass

    #####################################
    def SetParamFile(self, filepath=""):
        """
        Set file to be imported parameters.
        @param filepath (String) path to xml file.
        @return None
        """
        if filepath!="":
            self.filepath = filepath
        
        if os.path.exists(self.filepath):
            fd = file(self.filepath,'rb')
            dom = ElementTree(file=fd)
            self.root_ele = dom.getroot()
            fd.close()
        else:
            print self.CommentHead + "Cannot read file. :"+self.filepath
            raise

    #####################################
    def LoadVisualContParams(self):
        """
        Import parameters to handle VisCont.
        @params None
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            return
        
        # import the information of lattice constants from XML file
        #self.smpInfo = VCC.SampleInfo(None)
        self.smpInfo = SampleInfo(None)
        
        smpInfo_ele = self.root_ele.find("sampleInformation")
        sliceInfo_ele = self.root_ele.find("slicingInformation")

        lattice_ele = smpInfo_ele.find("latticeInfo")
        lconst_text = lattice_ele.find("latticeConst").text
        langle_text = lattice_ele.find("latticeAngle").text
        orient_ele = smpInfo_ele.find("orientation")
        Uvec_text = orient_ele.find("Uvector").text
        Vvec_text = orient_ele.find("Vvector").text
        ##[inamura 160621]-->
        rotSteps_ele = orient_ele.find("rotateSteps") 
        if rotSteps_ele!=None:
            rotSteps_text = rotSteps_ele.text
            rotSteps_list = rotSteps_text.split(",")
            for a_step in rotSteps_list:
                vals = a_step.split(":")
                if len(vals)==2:
                    if vals[0]=="x" or vals[0]=="X":
                        self.smpInfo.rotSteps.append( ["X",float(vals[1] ) ] )
                    elif vals[0]=="y" or vals[0]=="Y":
                        self.smpInfo.rotSteps.append( ["Y",float(vals[1] ) ] )
                    elif vals[0]=="z" or vals[0]=="Z":
                        self.smpInfo.rotSteps.append( ["Z",float(vals[1] ) ] )
                    else:
                        raise UserWarning, "RotateSteps info is invalid."
        ##<--[inamura 160621]

        ##[inamura 110727]-->
        phi_ele = orient_ele.find("phi")
        if phi_ele==None:
            phi_text = orient_ele.find("fai").text
            print "VisContMParam >> This param file is old version."
        else:
            phi_text = phi_ele.text
        ##<--[inamura 110727]
        LC = lconst_text.split(",")
        LA = langle_text.split(",")
        UV = Uvec_text.split(",")
        VV = Vvec_text.split(",")

        self.smpInfo.a = float(LC[0])
        self.smpInfo.b = float(LC[1])
        self.smpInfo.c = float(LC[2])
        self.smpInfo.alpha = float(LA[0])
        self.smpInfo.beta  = float(LA[1])
        self.smpInfo.gamma = float(LA[2])
        self.smpInfo.uh = float(UV[0])
        self.smpInfo.uk = float(UV[1])
        self.smpInfo.ul = float(UV[2])
        self.smpInfo.vh = float(VV[0])
        self.smpInfo.vk = float(VV[1])
        self.smpInfo.vl = float(VV[2])

        self.smpInfo.fai = float(phi_text) ##[inamura 110727]

        # import parameters for the projection
        self.proj_axes = {}
        project_ele = sliceInfo_ele.find("projectParams")
        axis_ele_list = project_ele.findall("axis")
        
        for item in axis_ele_list:
            id = item.get("id")
            vec_el = item.find("vector")
            lt = vec_el.text.split(",")
            title = item.find("title").text
            self.proj_axes[id]=[ float(lt[0]),float(lt[1]),float(lt[2]),float(lt[3]),title ]

        # import parameters for slicing using projection parameters
        plot_ele = sliceInfo_ele.find("plotParams")
        paxis_ele_list = plot_ele.findall("paxis")
        print self.CommentHead + "num of paxis elements = ",len(paxis_ele_list)
        self.paxis_info = {}
        
        for ele in paxis_ele_list:
            id_str = ele.get("id")
            #print "id=",id_str
            type_str = ele.find("type").text
            if not self.type_dic.has_key( type_str ):
                print self.CommentHead + "type is invalid at id=",id_str
                raise
            else:
                self.type_dic[ type_str ]+=1

            range_axis = []
            if type_str!="p":
                range_str = ele.find("range").text
                range_list = range_str.split(",")
                for item in range_list:
                    range_axis.append( float(item) )
                if len(range_list)==2:
                    range_axis.append( range_axis[1]-range_axis[0] )

            folding_str = ele.find("folding").text
            if (folding_str==None) or (not (folding_str in ["0","1"]) ):
                folding=0
            else:
                folding=int(folding_str)
            
            self.paxis_info[id_str] = ( type_str, range_axis, folding )

        if (self.type_dic["x"]==1) and (self.type_dic["y"]==1):
            if (self.type_dic["p"]==1) and (self.type_dic["t"]==1):
                self.EnableVisType="VisualCont"
            elif (self.type_dic["p"]==0) and (self.type_dic["t"]==2):
                self.EnableVisType="VisualCont2"

    #####################################
    def SetLatticeConst(self,LC=[],LA=[]):
        """
        Set Lattice constant
        @param LC (list of float) Lattice constants [Angstrome]
        @[aram LA (list of float) Lattice angles [degree]
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            raise

        smpInfo_ele = self.root_ele.find("sampleInformation")
        lattice_ele = smpInfo_ele.find("latticeInfo")
        
        if len(LC)==3:
            self.smpInfo.a = float(LC[0])
            self.smpInfo.b = float(LC[1])
            self.smpInfo.c = float(LC[2])
            lattice_ele.find("latticeConst").text = "%f, %f, %f" % (self.smpInfo.a, self.smpInfo.b, self.smpInfo.c)
        if len(LA)==3:
            self.smpInfo.alpha = float(LA[0])
            self.smpInfo.beta  = float(LA[1])
            self.smpInfo.gamma = float(LA[2])            
            lattice_ele.find("latticeAngle").text = "%f, %f, %f" % (self.smpInfo.alpha, self.smpInfo.beta, self.smpInfo.gamma)

    #####################################
    def SetOrientationVect(self,Uvec=[],Vvec=[]):
        """
        Set Sample Orientation information
        @param Uvec (list of float) U vector (parallel to ki)
        @param Vvec (list of float) V vector (perpendicular to ki)
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            raise

        smpInfo_ele = self.root_ele.find("sampleInformation")
        orient_ele = smpInfo_ele.find("orientation")
        
        if len(Uvec)==3:
            self.smpInfo.uh = float(Uvec[0])
            self.smpInfo.uk = float(Uvec[1])
            self.smpInfo.ul = float(Uvec[2])
            orient_ele.find("Uvector").text = "%f, %f, %f" % (self.smpInfo.uh, self.smpInfo.uk, self.smpInfo.ul)
        if len(Vvec)==3:
            self.smpInfo.vh = float(Vvec[0])
            self.smpInfo.vk = float(Vvec[1])
            self.smpInfo.vl = float(Vvec[2])        
            orient_ele.find("Vvector").text = "%f, %f, %f" % (self.smpInfo.vh, self.smpInfo.vk, self.smpInfo.vl)

    #####################################
    def SetOrientationFai(self,fai=None):
        """
        Set Sample orientation angle
        @param fai (float) angle between U vector and ki vector [degree]
        @param return
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            raise
        
        if fai!=None:
            self.smpInfo.fai = float(fai)
            smpInfo_ele = self.root_ele.find("sampleInformation")
            orient_ele = smpInfo_ele.find("orientation")
            orient_ele.find("phi").text = "%f" % (self.smpInfo.fai)


    #####################################
    def SetProjectionInfo(self,terget_id=-1,vect=[],title=""):
        """
        Set Projection information
        @param terget_id (int) ID for given axis
        @param vect      (list of float) vector for axis
        @param title     (string) title of axis
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            raise

        if not (target_id in [0,1,2,3]):
            print self.CommentHead + "ID is invalid!!!"
            raise

        if len(vect)!=3:
            print self.CommentHead + "Vector is invalid!!!"
            raise
        
        sliceInfo_ele = self.root_ele.find("slicingInformation")
        project_ele = sliceInfo_ele.find("projectParams")
        axis_ele_list = project_ele.findall("axis")
        for item in axis_ele_list:
            id = item.get("id")
            if int(id) == target_id:
                self.proj_axes[id]=[ vect[0], vect[1], vect[2], vect[3], title ]
                item.find("vector").text = "%f, %f, %f, %f" % ( vect[0],vect[1],vect[2],vect[3] )
                item.find("title").text = title

    #####################################
    def SetSliceInfo(self,target_id=-1,type="",axrange=[],folding=False):
        """
        Set Slicing parameters
        @param target_id (int) ID for axis
        @param type      (string) "x":x-axis, "y":y-axis, "p":projection axis, "t":thickness
        @param axrange   (list)
        @param folding   (bool) folding flag (True/False)
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            raise
        if not (target_id in [0,1,2,3]):
            print self.CommentHead + "ID is invalid!!!"
            raise

        if not (type in self.type_dic):
            print self.CommentHead + "Type is invalid!!! ( Choose x, y, p, t )"
            raise
        
        if (len(axrange)!=2) and (len(axrange)!=3):
            print self.CommentHead + "Vector is invalid!!!"
            raise

        sliceInfo_ele = self.root_ele.find("slicingInformation")
        plot_ele = sliceInfo_ele.find("plotParams")
        paxis_ele_list = plot_ele.findall("paxis")

        
        for ele in paxis_ele_list:
            if int(ele.get("id"))==target_id:
                ele.find("type").text = type
                if (len(axrange)==2) and ( (type=="p") or (type=="t") ):
                    ele.find("range").text = "%f, %f, %f" % (axrange[0],axrange[1],(axrange[1]-axrange[0]))
                elif (len(axrange)==3) and ( (type=="p") or (type=="t") ):
                    ele.find("range").text = "%f, %f, %f" % (axrange[0],axrange[1],axrange[2])
                elif (len(axrange)==3) and ( (type=="x") or (type=="y") ):
                    ele.find("range").text = "%f, %f, %f" % (axrange[0],axrange[1],axrange[2])
                else:
                    print self.CommentHead + "Type and range is not mutch."
                    raise
                if folding:
                    fol = 1
                else:
                    fol = 0
                    
                self.paxis_info[str(target_id)] = ( type, axrange, fol )

        self.type_dic={"x":0,"y":0,"p":0,"t":0}
        for ele in paxis_ele_list:
            type_str = ele.find("type").text
            self.type_dic[ type_str ] += 1

        
        self.EnableVisType=None
        if (self.type_dic["x"]==1) and (self.type_dic["y"]==1):
            if (self.type_dic["p"]==1) and (self.type_dic["t"]==1):
                self.EnableVisType="VisualCont"
            elif (self.type_dic["p"]==0) and (self.type_dic["t"]==2):
                self.EnableVisType="VisualCont2"
                
    #####################################            
    def MakeNewParams(self):
        """
        Import new format for parameter.
        @param None
        @return None
        """
        xml_st = self.GetParamFileTemplete()
        #self.root_ele = fromstring(xml_st)
        self.root_ele = XML(xml_st)
        self.LoadVisualContParams()

    ##[inamura 110205]-->
    #####################################
    def SetAllInfo(self,smpInfo_in,axisInfo=[],sliceInfo=[]):
        """
        axisInfo= [ [ax1_a, ax1_b, ax1_c, ax1_hw, ax1_title],
                    [ax2_a, ax2_b, ax2_c, ax2_hw, ax2_title],
                    [ax3_a, ax3_b, ax3_c, ax3_hw, ax3_title],
                    [ax4_a, ax4_b, ax4_c, ax4_hw, ax4_title] ]
        sliceInfo=[ [type1, ax1_min, ax1_max, ax1_step, ax1_folding ],
                    ...
                    [type4, ax4_min, ax4_max, ax4_step, ax4_folding ] ]
        @param smpInfo_in (smpInfo class)
        @param axisInfo   (list of axis info)
        @param sliceInfo  (list of slicing parameter)
        @return None
        """
        self.smpInfo = smpInfo_in
        self.root_ele = XML( self.GetParamFileTemplete() )
        smpInfo_ele = self.root_ele.find("sampleInformation")
        
        lattice_ele = smpInfo_ele.find("latticeInfo")
        lattice_ele.find("latticeConst").text ="%f, %f, %f"% (self.smpInfo.a, self.smpInfo.b, self.smpInfo.c)
        lattice_ele.find("latticeAngle").text = "%f, %f, %f" % (self.smpInfo.alpha, self.smpInfo.beta, self.smpInfo.gamma)
        
        orient_ele = smpInfo_ele.find("orientation")
        orient_ele.find("Uvector").text = "%f, %f, %f" % (self.smpInfo.uh, self.smpInfo.uk, self.smpInfo.ul)
        orient_ele.find("Vvector").text = "%f, %f, %f" % (self.smpInfo.vh, self.smpInfo.vk, self.smpInfo.vl)
        #orient_ele.find("fai").text = "%f" % (self.smpInfo.fai)
        orient_ele.find("phi").text = "%f" % (self.smpInfo.fai)
        
        self.proj_axes = {}
        
        sliceInfo_ele = self.root_ele.find("slicingInformation")
        project_ele = sliceInfo_ele.find("projectParams")
        axis_ele_list = project_ele.findall("axis")

        for (i,axis) in enumerate(axis_ele_list):
            self.proj_axes[str(i)]=[axisInfo[i][0],axisInfo[i][1],axisInfo[i][2],axisInfo[i][3]
                                    ,axisInfo[i][4]]
            axis.find("vector").text = "%f, %f, %f, %f" % ( axisInfo[i][0],axisInfo[i][1],axisInfo[i][2],axisInfo[i][3] )
            axis.find("title").text = axisInfo[i][4]
        
        
        self.paxis_info = {}
        
        plot_ele = sliceInfo_ele.find("plotParams")
        paxis_ele_list = plot_ele.findall("paxis")
        for (i,paxis) in enumerate(paxis_ele_list):
            paxis.find("type").text = sliceInfo[i][0]
            if (sliceInfo[i][0]=="t") and ( len(sliceInfo[i])==2 ):
                axrange = [sliceInfo[i][1],sliceInfo[i][2]]
                paxis.find("range").text = "%f, %f, %f" % (axrange[0],axrange[1],(axrange[1]-axrange[0]))
            elif (sliceInfo[i][0] in ["x","y","t"]):
                axrange = [sliceInfo[i][1],sliceInfo[i][2],sliceInfo[i][3]]
                paxis.find("range").text = "%f, %f, %f" % (axrange[0],axrange[1],axrange[2])
            else:
                axrange = []
                
            paxis.find("folding").text = str(sliceInfo[i][4])

            self.paxis_info[str(i)] = ( sliceInfo[i][0], axrange, int(sliceInfo[i][4]) )

        self.type_dic={"x":0,"y":0,"p":0,"t":0}
        for ele in paxis_ele_list:
            type_str = ele.find("type").text
            self.type_dic[ type_str ] += 1

        
        self.EnableVisType=None
        if (self.type_dic["x"]==1) and (self.type_dic["y"]==1):
            if (self.type_dic["p"]==1) and (self.type_dic["t"]==1):
                self.EnableVisType="VisualCont"
            elif (self.type_dic["p"]==0) and (self.type_dic["t"]==2):
                self.EnableVisType="VisualCont2"
        
    ##<--[inamura 110205]
        
    #####################################
    def ShowParams(self):
        """
        Show all parameters
        @param None
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import file."
            raise
        print "Lattice constants"
        print "a = %f" % self.smpInfo.a
        print "b = %f" % self.smpInfo.b
        print "c = %f" % self.smpInfo.c
        print "alpha = %f" % self.smpInfo.alpha
        print "beta  = %f" % self.smpInfo.beta
        print "gamma = %f" % self.smpInfo.gamma
        print "---"
        print "Sample orientation"
        print "Uvec = [ %f, %f, %f ]" % (self.smpInfo.uh,self.smpInfo.uk,self.smpInfo.ul)
        print "Vvec = [ %f, %f, %f ]" % (self.smpInfo.vh,self.smpInfo.vk,self.smpInfo.vl)
        print "phi = %f" % self.smpInfo.fai
        print "---"
        print "Projection"
        proj_keys = self.proj_axes.keys()
        proj_keys.sort()
        for pkey in proj_keys:
            [lt0,lt1,lt2,lt3,title]=self.proj_axes[pkey]
            print "ID(%s): [%f,%f,%f,%f] :%s" % (pkey,lt0,lt1,lt2,lt3,title)

        print "---"
        print "Slicing"
        SS = ""
        paxis_ids = self.paxis_info.keys()
        paxis_ids.sort()
        for id in paxis_ids:
            (type_str, range_axis, folding) = self.paxis_info[id]
            SS = "ID(%s) : Type=%s : " % (id,type_str)
            for rr in range_axis:
                SS += " %f," % rr
            SS += " Folding=%d" % folding
            print SS

    #####################################
    def ShowXML(self):
        """
        Show XML introduced from element
        @param None
        @return None
        """
        print tostring(self.root_ele)

    #####################################
    def SaveXML(self,filename=""):
        """
        Save parameter to XML file
        @param filename (string) path and name of xml file to be saved
        @return None
        """
        if self.root_ele == None:
            print self.CommentHead + "You did not import nor make parameters."
            raise

        if os.path.exists(filename):
            print self.CommentHead+filename+" is already existed."
            
        try:
            fd = open( filename,"w" )
            fd.write( '<?xml version="1.0" encoding="utf-8"?>\n' )
            fd.write( tostring(self.root_ele) )
            fd.close()
        except:
            print self.CommentHead + " failed save to file."
            raise
        
    #####################################            
    def GetParamFileTemplete(self):
        """
        Return the templete for XML file
        @param None
        @return string of XML
        """
        return """

<visualContParams version="0.2">
  <sampleInformation>
    <name>CuGeO3</name>
    <latticeInfo>
      <latticeConst>4.81, 8.47, 2.941</latticeConst>
      <latticeAngle>90.0, 90.0, 90.0</latticeAngle>
    </latticeInfo>
    <orientation>
      <Uvector>0.0, 1.0, 0.0</Uvector>
      <Vvector>0.0, 0.0, 1.0</Vvector>
      <phi>0.0</phi>
    </orientation>
  </sampleInformation>
  <slicingInformation>
    <projectParams>
      <axis id="0">
        <vector>1.0, 0.0, 0.0, 0.0</vector>
        <title>Qa</title>
      </axis>
      <axis id="1">
        <vector>0.0, 1.0, 0.0, 0.0</vector>
        <title>Qb</title>
      </axis>
      <axis id="2">
        <vector>0.0, 0.0, 1.0, 0.0</vector>
        <title>Qc</title>
      </axis>
      <axis id="3">
        <vector>0.0, 0.0, 0.0, 1.0</vector>
        <title>hw</title>
      </axis>    
    </projectParams>

    <plotParams>
      <paxis id="0">
        <type>t</type>
        <range>-5.0,5.0,0.05</range>
        <folding>0</folding>
      </paxis>
      <paxis id="1">
        <type>p</type>
        <range></range>
        <folding>0</folding>
      </paxis>
      <paxis id="2">
        <type>x</type>
        <range>-1.5,2.0,0.02</range>
        <folding>1</folding>
      </paxis>
      <paxis id="3">
        <type>y</type>
        <range>-5.0,40.0,0.5</range>
        <folding>0</folding>
      </paxis>

    </plotParams>
  </slicingInformation>
</visualContParams>
"""
      



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import utsusemi.SAS.ana.Reduction.HistBaseCommands as HBC

# reserved words for return value in this.
DAT = None
ecs = None
EC = None
ret = None
PyObj = None
Iq = None
Tr = None


########################################
def GetHistogramSAS( runNo=0, Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlice="-1 -1", frameBoundary="0.0", isTimeFoc=False, SolAngCor=True, paramFiles="- -" ):
    """
    Load EventData to produce histogram
    GetHistogramSAS( runNo=0, AxType="lambda", Xrange="0.7 7.7 0.05", Bank="SM", TimeSlice="-1 -1", frameBoundary="0.0", isTimeFoc=False )
    
    @param runNo     (int)     Run Number
    @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof]
    @param Bank      (string)  "SM"...  Monitors by "MON1" or "MON2"
    @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
    @param frameBoundary (string) "frameBoundary" or "frameBoundary TofMask_min TofMask_max"
    @param isTimeFoc (bool)    True or False
    @param SolAngCor  (bool)    True or False for Solid Angle Correction
    @param paramFiles (string) "WiringInfo DetectorInfo"
    @retval DAT (ElementContainerMatrix)
    """
    return HBC.GetHistogramSAS( runNo, Xrange, Bank, TimeSlice, frameBoundary, isTimeFoc, SolAngCor, paramFiles )

########################################
def GetMonHistSAS( runNo=0, MonNo=1, AxType="lambda", Xrange="0.7 7.6 0.1", MonIndex=0, TimeSlice="-1 -1", frameBoundary="0.0", CalibEffi=True ):
    """
    Load EventData to produce histogram of monitors
    GetMonHistSAS( runNo=0, MonNo=1, AxType="lambda", Xrange="0.7 7.7 0.05", MonIndex=0, TimeSlice="-1 -1", frameBoundary="0.0", CalibEffi=True )
    
    @param runNo     (int)     Run Number
    @param MonNo     (int)     Monitor Number 1 (up-stream) or 2 (down-stream)
    @param AxType    (string)  Type must be "tof', "lambda" or "lamda2"
    @param Xrange    (string)  "startX endX widthX" separated with space (not comma)
    @param MonIndex  (int)     
    @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
    @param frameBoundary (string) "frameBoundary" or "frameBoundary TofMask_min TofMask_max"
    @param CalibEffi (bool)    Monitor-detector efficiency calibration
    @retval EC (ElementContainer)
    """
    return HBC.GetMonHistSAS( runNo, MonNo, AxType, Xrange, MonIndex, TimeSlice, frameBoundary, CalibEffi )

########################################
def GetPulseHeightSAS( runNo=0, Xrange="0 40000 100", Bank="SM", TimeSlice="-1 -1", frameBoundary="0.0", paramFiles="- -",PHbin=5 ):
    """
    Make Pulse Height data of EventData
    GetPulseHeightSAS( runNo=0, Xrange="0 10000 10", Bank="SM", TimeSlice="-1 -1", paramFiles="- -" ):
    
    @param runNo     (int)     Run Number
    @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof]
    @param Bank      (string)  "SM"...  Monitors by "MON1" or "MON2"
    @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
    @param frameBoundary (string) "frameBoundary" or "frameBoundary TofMask_min TofMask_max"
    @param paramFiles (string) "WiringInfo DetectorInfo"
    @param PHbin      (int)    Pulse Height bin
    @retval ECM (ElementContainerMatrix)
    """
    return HBC.GetPulseHeightSAS( runNo, Xrange, Bank,TimeSlice, frameBoundary, paramFiles, PHbin)

########################################
def GetMonHistByPhSAS( runNo=0, MonNo=1, Xrange="0.0 40000.0 10.0 tof", phRange="0 10000", MonIndex=0, TimeSlice="-1 -1", frameBoundary=0.0, CalibEffi=True ):
    """
    Load EventData to produce histogram of monitors limited by pulse height
    GetMonHistByPhSAS( runNo=0, MonNo=1, Xrange="0.0 40000.0 10.0 tof", phRange="0 10000", MonIndex=0, TimeSlice="-1 -1", frameBoundary=0.0, CalibEffi=True )
    
    @param runNo     (int)     Run Number
    @param MonNo     (int)     Monitor Number 1 (up-stream) or 2 (down-stream)
    @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof]
    @param phRange   (string)  "lld hld" 
    @param MonIndex  (int)     0.. digital  1.. analog
    @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
    @param frameBoundary (float) 
    @param CalibEffi (bool)    Monitor-detector efficiency calibration
    @retval EC (ElementContainer)
    """
    return HBC.GetMonHistByPhSAS( runNo, MonNo, Xrange, phRange, MonIndex, TimeSlice, frameBoundary, CalibEffi )

########################################
def MergeSMSC4DetMap(dat=DAT):
    """ 
    Merge Data SM and SC bank into one ElementContainerMatrix 
    to plot using DetectMap
    @param dat  [Def:DAT] (ElementContainerMatrix) 
    @retval ECM (ElementContainerMatrix)
    """
    return HBC.MergeSMSC4DetMap(dat)

########################################
def GetHistogramRPMT( runNo=0, isLambda=True ):
    """
    Load EventData to produce histogram
    GetHistogramSAS( runNo=0, AxType="lambda", Xrange="0.7 7.7 0.05", Bank="SM", TimeSlice="-1 -1", frameBoundary=0.0, isTimeFoc=False )
    
    @param runNo     (int)     Run Number
    @retval DAT (ElementContainerMatrix)
    """
    return HBC.GetHistogramRPMT( runNo, isLambda )

########################################
def RPMTRemoveCenterLine( dat=DAT, PsdRange="200 201", PixelRange="198 199" ):
    """ 
    Merge Data SM and SC bank into one ElementContainerMatrix 
    to plot using DetectMap
    @param dat  [Def:DAT] (ElementContainerMatrix) 
    @param PsdRange
    @param PixelRange
    @retval None
    """
    HBC.RPMTRemoveCenterLine( dat, PsdRange, PixelRange )
     
    
########################################
# Dictionary for entry the name of functions
_functions = {
            "GetHistogramSAS":GetHistogramSAS,
            "GetMonHistSAS":GetMonHistSAS,
            "GetPulseHeightSAS":GetPulseHeightSAS,
            "GetMonHistByPhSAS":GetMonHistByPhSAS,
            "MergeSMSC4DetMap":MergeSMSC4DetMap,
            "GetHistogramRPMT":GetHistogramRPMT,
            "RPMTRemoveCenterLine":RPMTRemoveCenterLine
            }
_functionsOrder = [
    "GetHistogramSAS",
    "GetMonHistSAS",
    "GetPulseHeightSAS",
    "GetMonHistByPhSAS",
    "MergeSMSC4DetMap",
    "GetHistogramRPMT",
    "RPMTRemoveCenterLine"
    ]
    



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'test/uic007.ui',
# licensing of 'test/uic007.ui' applies.
#
# Created: Sun Feb 17 19:52:38 2019
#      by: pyside2-uic  running on PySide2 5.11.0
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(620, 372)
        MainWindow.setMaximumSize(QtCore.QSize(1200, 600))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem = QtWidgets.QSpacerItem(195, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 2, 4, 1, 1)
        self.browsePriv = QtWidgets.QPushButton(self.centralwidget)
        self.browsePriv.setMinimumSize(QtCore.QSize(80, 0))
        self.browsePriv.setMaximumSize(QtCore.QSize(80, 16777215))
        self.browsePriv.setObjectName("browsePriv")
        self.gridLayout.addWidget(self.browsePriv, 2, 5, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(self.centralwidget)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 8, 4, 1, 2)
        self.textPriv = QtWidgets.QTextEdit(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textPriv.sizePolicy().hasHeightForWidth())
        self.textPriv.setSizePolicy(sizePolicy)
        self.textPriv.setMinimumSize(QtCore.QSize(0, 48))
        self.textPriv.setMaximumSize(QtCore.QSize(16777215, 48))
        self.textPriv.setObjectName("textPriv")
        self.gridLayout.addWidget(self.textPriv, 3, 3, 1, 3)
        self.browseData = QtWidgets.QPushButton(self.centralwidget)
        self.browseData.setObjectName("browseData")
        self.gridLayout.addWidget(self.browseData, 0, 5, 1, 1)
        self.beamList = QtWidgets.QListWidget(self.centralwidget)
        self.beamList.setMinimumSize(QtCore.QSize(250, 120))
        self.beamList.setMaximumSize(QtCore.QSize(250, 120))
        self.beamList.setObjectName("beamList")
        self.gridLayout.addWidget(self.beamList, 1, 0, 2, 2)
        self.label_5 = QtWidgets.QLabel(self.centralwidget)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 2, 3, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(195, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 4, 1, 1)
        self.checkYes = QtWidgets.QCheckBox(self.centralwidget)
        self.checkYes.setObjectName("checkYes")
        self.gridLayout.addWidget(self.checkYes, 3, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.centralwidget)
        self.label_6.setMinimumSize(QtCore.QSize(120, 24))
        self.label_6.setMaximumSize(QtCore.QSize(120, 24))
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 0, 0, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(272, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem2, 8, 0, 1, 4)
        self.textData = QtWidgets.QTextEdit(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textData.sizePolicy().hasHeightForWidth())
        self.textData.setSizePolicy(sizePolicy)
        self.textData.setMinimumSize(QtCore.QSize(0, 48))
        self.textData.setMaximumSize(QtCore.QSize(16777215, 48))
        self.textData.setObjectName("textData")
        self.gridLayout.addWidget(self.textData, 1, 3, 1, 3)
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 0, 3, 1, 1)
        self.line = QtWidgets.QFrame(self.centralwidget)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout.addWidget(self.line, 0, 2, 7, 1)
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 6, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 3, 0, 1, 1)
        self.spinThreads = QtWidgets.QSpinBox(self.centralwidget)
        self.spinThreads.setMinimumSize(QtCore.QSize(60, 24))
        self.spinThreads.setMaximumSize(QtCore.QSize(60, 24))
        self.spinThreads.setObjectName("spinThreads")
        self.gridLayout.addWidget(self.spinThreads, 6, 1, 1, 1)
        self.checkDebug = QtWidgets.QCheckBox(self.centralwidget)
        self.checkDebug.setObjectName("checkDebug")
        self.gridLayout.addWidget(self.checkDebug, 4, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 4, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 620, 18))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtWidgets.QToolBar(MainWindow)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.toolBar_2 = QtWidgets.QToolBar(MainWindow)
        self.toolBar_2.setObjectName("toolBar_2")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar_2)
        self.toolBar_3 = QtWidgets.QToolBar(MainWindow)
        self.toolBar_3.setObjectName("toolBar_3")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar_3)
        self.toolBar_4 = QtWidgets.QToolBar(MainWindow)
        self.toolBar_4.setObjectName("toolBar_4")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar_4)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setProperty("DlgSetUtsusemiEnv", QtWidgets.QApplication.translate("MainWindow", "MainWindow", None, -1))
        self.browsePriv.setText(QtWidgets.QApplication.translate("MainWindow", "Browse", None, -1))
        self.browseData.setText(QtWidgets.QApplication.translate("MainWindow", "Browse", None, -1))
        self.label_5.setText(QtWidgets.QApplication.translate("MainWindow", "USR_DIR", None, -1))
        self.checkYes.setText(QtWidgets.QApplication.translate("MainWindow", "Yes", None, -1))
        self.label_6.setText(QtWidgets.QApplication.translate("MainWindow", "Instrument", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("MainWindow", "DATA_DIR", None, -1))
        self.label_3.setText(QtWidgets.QApplication.translate("MainWindow", "Number of threads", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("MainWindow", "Log quiet", None, -1))
        self.checkDebug.setText(QtWidgets.QApplication.translate("MainWindow", "Yes", None, -1))
        self.label_2.setText(QtWidgets.QApplication.translate("MainWindow", "Utsusemi_debugmode", None, -1))
        self.toolBar.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "toolBar", None, -1))
        self.toolBar_2.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "toolBar_2", None, -1))
        self.toolBar_3.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "toolBar_3", None, -1))
        self.toolBar_4.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "toolBar_4", None, -1))




#!/bin/env python
# -*- coding: utf-8 -*-
#
# Usage: runlist.py initial_run_no [final_run_no]
#    initial_run_no, final_run_no:
#       range of run numbers to be listed.
#    -np: does not show proton counts

from __future__ import print_function
import sys
import os
import glob
import Manyo as mm
import Manyo.Utsusemi as mu
import utsusemi.ana.Reduction.BaseCommands as BC

ver = float(sys.version_info[0]) + float(sys.version_info[1]) * 0.1
if ver < 2.5:
    from elementtree.ElementTree import ElementTree
else:
    from xml.etree.ElementTree import ElementTree

#########################################


def usage(argv):
    print("------------------------------------------------------------------------")
    print("Usage  %s [option] initial_run_no [final_run_no]" % (argv[0]))
    print("       initial_run_no, final_run_no : range of run numbers to be listed.")
    print("------------------------------------------------------------------------")
    print("Option")
    print("       -np         : does not show proton counts")
    print("       -f filename : saves the list as a text file named filename")
    print("------------------------------------------------------------------------")
    sys.exit(0)

#########################################
# copied from GetMeasBC.py by Y. Inamura


def GetMeasBC(runNo, flag_proton, offset_sec=0.0, isCT8Neutron=False):
    TT = mu.T0TreatToolsNeunet()
    st_RUNNO = "%3s%06d" % (os.environ["UTSUSEMI_INST_CODE"], runNo)

    root_data_dir = os.environ["UTSUSEMI_DATA_DIR"]
    inst_code = os.environ["UTSUSEMI_INST_CODE"]
    list_DATA_folder = os.listdir(root_data_dir)
    target_dir = ""

    list_DATA_folder.sort()
    for a_DATA_folder in list_DATA_folder:
        if a_DATA_folder.find(inst_code) < 0:
            continue

        a_path = os.path.join(root_data_dir, a_DATA_folder)
        if os.path.isdir(a_path):
            list_DATA = os.listdir(a_path)
            for a_data_dir in list_DATA:
                if a_data_dir.find(st_RUNNO) == 0:
                    target_dir = os.path.join(a_path, a_data_dir)
                    break
        if target_dir != "":
            break

    if target_dir == "":
        err_message = "There is no data;{}".format(st_RUNNO)
        raise UserWarning(err_message)
    print("target_dir={}".format(target_dir))
    edb_list = glob.glob(target_dir + "/*.edb")
    edb_list.sort()
    first_file = edb_list[0]
    edb_list = glob.glob(target_dir + "/%s*.edb" % (first_file[-24:-7]))
    edb_list.sort()

    if len(edb_list) == 0:
        err_message = "There is no edb data;{}".format(st_RUNNO)
        raise UserWarning(err_message)
    target_edb = mm.MakeStringVector()
    for a_file in edb_list:
        target_edb.append(a_file)

    TT.readOrgEvent(target_edb)
    mpv2 = TT.putMeasPeriodFromT0()

    mpv = mm.MakeDoubleVector()
    for i in range(7):
        mpv.append(mpv2[i])
    for i in range(7):
        mpv.append(mpv2[mpv2.size() - 1 - 6 + i])
    if mpv.size() != 14:
        err_message = "False to get measuring period from Event Data"
        raise UserWarning(err_message)
    start_date = "%04d/%02d/%02d" % (int(mpv[0]), int(mpv[1]), int(mpv[2]))
    start_time = "%02d:%02d:%02d" % (int(mpv[3]), int(mpv[4]), int(mpv[5]))
    end_date = "%04d/%02d/%02d" % (int(mpv[7]), int(mpv[8]), int(mpv[9]))
    end_time = "%02d:%02d:%02d" % (int(mpv[10]), int(mpv[11]), int(mpv[12]))

    proton = "     ---  "
    kicker = "     ---  "
    if flag_proton == 0:  # does not show proton counts
        pass
    else:  # show proton counts
        #        print "NormByBeamCurrent(runNo=%d)" % runNo
        #        print "     begin date and time = ",start_date," ",start_time
        #        print "       end date and time = ",end_date," ",end_time
        if flag_proton == 1 or flag_proton == 3:
            bc, ratio, org_bc = BC.getBeamCurrentWithCorrectRatio(
                start_date, start_time, end_date, end_time, offset_sec, isCT8Neutron)
            proton = "%14.4f" % (bc)
        if flag_proton == 2 or flag_proton == 3 or flag_proton == 4:
            kk = TT.PutT0Index()
            kicker = "%10d" % (int(kk.size()))
        if flag_proton == 4:
            bc, ratio, org_bc = BC.getBeamCurrentWithCorrectRatio(
                start_date, start_time, end_date, end_time, offset_sec, isCT8Neutron)
            proton = "%14.4f %10g %g" % (bc, org_bc, ratio)

    del TT
    return (runNo, start_date, start_time, end_date, end_time, proton, kicker)

#########################################


def MakeRunList(argv):
    ET = ElementTree()

    Output = []  # list where the output is stored

    # header of the output
    # Output.append("  run#           start                 end              protons     T_A    T_B     gonio")

    argc = len(argv)  # number of argument
    if (argc < 2):
        usage(argv)  # show help and exit

    flag_proton = 1
    offset_sec = 0.0
    # analysis arguments
    output_name = ""
    init_no = -1
    fin_no = -1
    ind = 1
    isCT8Neutron = False
    while(True):
        if argv[ind] == "-np":  # if no use of procton current
            flag_proton = 0
        elif argv[ind] == "-p":
            flag_proton = 1
        elif argv[ind] == "-k":
            flag_proton = 2
        elif argv[ind] == "-pk" or argv[ind] == "-kp":
            flag_proton = 3
        elif argv[ind] == "-a" or argv[ind] == "-all":
            flag_proton = 4
        elif argv[ind] == "-f":  # set output file
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            output_name = argv[ind]
        elif argv[ind] == "-os":  # if use offset seconds for measurement periods
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            offset_sec = float(argv[ind])
        elif argv[ind] == "-CT8n":  # if use CT8Neutron
            isCT8Neutron = True
            # ind +=1
        else:
            if init_no < 0:
                init_no = int(argv[ind])
            else:
                fin_no = int(argv[ind])

        ind += 1
        if ind >= len(argv):
            break

    if init_no < 0:
        usage(argv)
    if fin_no < 0:
        fin_no = init_no

    run_no = init_no  # run number

    if isCT8Neutron:
        proton_source = "CT8n"
    else:
        proton_source = "CT9"
    if flag_proton == 0 or flag_proton == 1:
        Output.append(
            "  run#           start                 end              protons(%s)     T_A    T_B     gonio" % (proton_source))
    elif flag_proton == 2:
        Output.append(
            "  run#           start                 end                kickers     T_A    T_B     gonio")
    elif flag_proton == 3:
        Output.append(
            "  run#           start                 end                kickers    protons(%s)     T_A    T_B     gonio" % (proton_source))
    elif flag_proton == 4:
        Output.append(
            "  run#           start                 end           kickers        protons       %s   ratio     T_A    T_B     gonio" % proton_source)

    while(True):
        # xml file where the experimental condition is stored
        file = "%3s%06d.xml" % (os.environ["UTSUSEMI_INST_CODE"], run_no)
        file = os.path.join(os.environ["UTSUSEMI_USR_DIR"], "exp", "xml", file)

        # open the xml file
        e = ET.parse(open(file))

        # read the run number from xml file to check consistency
        runno = e.find(".//runNo").text
        runno = int(runno)

        # read set temperature
        temp_el = e.find(".//temperature")
        if temp_el is None:
            temp = "  --- "
        else:
            temp = "%6.2f" % (float(temp_el.text))

        # read temperature A
        temp_a_el = e.find(".//temperature_a")
        if temp_a_el is None:
            temp_a = "set_T="
        else:
            temp_a = "%6.2f" % (float(temp_a_el.text))

        # read temperature B
        temp_b_el = e.find(".//temperature_b")
        if temp_b_el is None:
            temp_b = temp
        else:
            temp_b = "%6.2f" % (float(temp_b_el.text))

        # read angle of the gonio
        gonio_el = e.find(".//curPos")
        if gonio_el is None:
            gonio = "    ---    "
        else:
            gonio = "%8.4f" % (float(gonio_el.text))

        # get proton current
        (runNo, s_date, s_time, e_date, e_time, proton, kicker) = GetMeasBC(
            runno, flag_proton, offset_sec, isCT8Neutron)

        # store the output in the list
        cnt = ""
        if flag_proton == 0 or flag_proton == 1:
            cnt = "%6d   %s %s   %s %s     %s   %s %s   %s" % (
                runno, s_date, s_time, e_date, e_time, proton, temp_a, temp_b, gonio)
        elif flag_proton == 2:
            cnt = "%6d   %s %s   %s %s     %s   %s %s   %s" % (
                runno, s_date, s_time, e_date, e_time, kicker, temp_a, temp_b, gonio)
        elif flag_proton == 3:
            cnt = "%6d   %s %s  %s %s      %s   %s   %s %s %s" % (
                runno, s_date, s_time, e_date, e_time, kicker, proton, temp_a, temp_b, gonio)
        elif flag_proton == 4:
            cnt = "%6d   %s %s  %s %s %s %s   %s %s %s" % (
                runno, s_date, s_time, e_date, e_time, kicker, proton, temp_a, temp_b, gonio)

        Output.append(cnt)

        run_no += 1
        if run_no > fin_no:
            break

    print()  # print blank line
    print("-----------------------------------------------------------------------------------------------------------------------")
    for out in Output:  # print the output
        print(out)
    print("-----------------------------------------------------------------------------------------------------------------------")

    # save as text file
    if output_name != "":
        print("     Output file={}".format(output_name))
        fo = open(output_name, "w")
        for out in Output:
            fo.write(out + "\n")
        fo.close()

#########################################


if __name__ == '__main__':
    MakeRunList(sys.argv)



from __future__ import print_function
import Manyo as mm
import Manyo.Utsusemi as mu
import Manyo.DNA as md
import os

from utsusemi.DNA.ana.Reduction.DefaultInstParams import *   #[inamura 120807]
import utsusemi.DNA.ana.Reduction.SearchPathDNA as SPD

__version__ = "0.6"

def GetHistogram(eventtype="PSD",runnumber=10,
                 WiringInfo_xml="WiringInfo.xml",
                 DetectorInfo_xml="DetectorInfo.xml",
                 CaseInfo_xml="",
                 ChopCondInfo_xml="",
                 TOFOffsetFile="",
                 useTrignet=0,
                 starttime=-1.0, endtime=-1.0,
                 isPH=False,
                 isHistogram=True):
    """
    Load EventData and convert to histogram on NEUNET system
    If you use this script, you must set some environment variables at least as below:
       UTSUSEMI_SYS_NAME   : "AMR" for BL14, "SIK" for BL01
       UTSUSEMI_DATA_DIR   : normaly use "/data"
       UTSUSEMI_USR_DIR    : normaly use "/opt/mlfsoft/python-utsusemi"
       Obsoleted environment variables : 
                             USE_E2H_MULTH
          
    @param eventtype (string) 'PSD' or 'N2MON'
    @param runnumber  (int) Run Number
    @param WiringInfo_xml (string) Detector Info xml file
    @param DetectorInfo_xml (string) Detector position setting file
    @param starttime (double) gives range of time to slice evnetdata
    @param endtime (double) gives range of time to slice evnetdata
    @param isPH (bool) make this true if pulse height is required
    @retval DAT        ElementContainerMatrix
    """
    if eventtype=="PSD" or eventtype=="N2MON" or eventtype=="uPSD" or eventtype=="SMPMON" or eventtype=="VANMON":
        #[add 140210 AS]--
        #if os.environ["UTSUSEMI_SYS_NAME"]=="DNA":
        instCode = mu.UtsusemiEnvGetInstCode()
        if instCode=="DNA":
            if useTrignet==4 or useTrignet==5 or useTrignet==6:
                if eventtype=="uPSD":
                    evt = md.UtsusemiEventDataConverterDNAWithHSC()
                    #[add 150218 AS]--
                    if TOFOffsetFile!="":
                        if os.path.exists(TOFOffsetFile):
                            pass
                        else:
                            #TOFOffsetFile=os.path.join(os.sep,"home","dnaadmin","ana","EOrg",TOFOffsetFile)
                            #TOFOffsetFile=os.path.join(os.sep,os.environ["UTSUSEMI_USR_PRIV_HOME"],"ana","EOrg",TOFOffsetFile)
                            ret= SPD.CheckForInput("EOrg",TOFOffsetFile)
                            if ret!="":
                                TOFOffsetFile = ret
                            else:
                                raise UserWarning("EventDataToEcm::GetHistogram >> TOFOffsetFile is not found. (%s)"%(TOFOffsetFile))
                        if os.path.exists(TOFOffsetFile):
                            print("load", TOFOffsetFile, "as TOFOffsetFile")
                            evt.SetTOFOffsetFile(TOFOffsetFile)
                    #--[add 150218 AS]

                elif eventtype=="PSD":
                    evt = mu.UtsusemiEventDataConverterNeunet()
                else:
                    evt = md.UtsusemiEventDataConverterDNAWithHSC()

            else:
                if eventtype=="uPSD":
                    evt = md.UtsusemiEventDataConverterDNA()
                    #[add 150218 AS]--
                    if TOFOffsetFile!="":
                        if os.path.exists(TOFOffsetFile):
                            pass
                        else:
                            #TOFOffsetFile=os.path.join(os.sep,"home","dnaadmin","ana","EOrg",TOFOffsetFile)
                            #TOFOffsetFile=os.path.join(os.sep,os.environ["UTSUSEMI_USR_PRIV_HOME"],"ana","EOrg",TOFOffsetFile)
                            TOFOffsetFile = SPD.CheckForInput("EOrg",TOFOffsetFile)
                        if os.path.exists(TOFOffsetFile):
                            print("load", TOFOffsetFile, "as TOFOffsetFile")
                            evt.SetTOFOffsetFile(TOFOffsetFile)
                    #--[add 150218 AS]
                elif eventtype=="PSD":
                    evt = mu.UtsusemiEventDataConverterNeunet()
                else:
                    evt = md.UtsusemiEventDataConverterDNA()
                    #evt = mu.UtsusemiEventDataConverterNeunet()
        else:
            evt = mu.UtsusemiEventDataConverterNeunet()
        #[add 140210 AS] original
        #evt = mu.UtsusemiEventDataConverterNeunet()
        #[add 140210 AS]--
    else:
        raise UserWarning("EvnetType argument is invalid.")

    
    CommentHead = "EventDataToEcm::GetHistogram >>> "
    print("--------------------------------------------------------------------")
    print("Load EventData using Manyo.Utsusemi.UtsusemiEventDataConverterNeunet")
    print("-------")
    
    #spectcode=os.environ["UTSUSEMI_SYS_NAME"]
    #datapath=os.environ["UTSUSEMI_DATA_DIR"]
    #t0datapath = os.path.join(os.environ["HOME"],"ana","tmp")
    spectcode=mu.UtsusemiEnvGetInstCode()
    datapath=mu.UtsusemiEnvGetDataDir()
    t0datapath = os.path.join(mu.UtsusemiEnvGetUserDir(),"ana","tmp")
    
    st_runno="%06d" % runnumber
    #if "UTSUSEMI_USR_PRIV_HOME" in os.environ:
    udir = mu.UtsusemiEnvGetUserDir()
    if udir!="":
        WIpath=os.path.join(udir,"ana","xml",WiringInfo_xml)
    else:
        #WIpath=os.path.join(os.environ["HOME"],"ana","xml",WiringInfo_xml)
        WIpath=os.path.join(mu.UtsusemiEnvGetUserDir(),"ana","xml",WiringInfo_xml)
    #print CommentHead,"wiring file path=",WIpath
    if not os.path.exists( WIpath ):
        #WIpath=os.path.join(os.environ["UTSUSEMI_USR_DIR"],"ana","xml",WiringInfo_xml)
        WIpath=os.path.join(mu.UtsusemiEnvGetBaseDir(),spectcode,"ana","xml",WiringInfo_xml)
        if not os.path.exists(WIpath):
            msg = CommentHead+"There is no wiring file.",WIpath
            print(msg)
            raise UserWarning(msg)
            
    #DCpath=os.path.join(os.environ["UTSUSEMI_USR_DIR"],"ana","xml",DetectorInfo_xml)
    #CCpath=os.path.join(os.environ["UTSUSEMI_USR_DIR"],"ana","xml",ChopCondInfo_xml)

    #20151202 start
    #DCpath=os.path.join(os.environ["HOME"],"ana","xml",DetectorInfo_xml)
    #CCpath=os.path.join(os.environ["HOME"],"ana","xml",ChopCondInfo_xml)
    DCpath=os.path.join(mu.UtsusemiEnvGetUserDir(),"ana","xml",DetectorInfo_xml)
    CCpath=os.path.join(mu.UtsusemiEnvGetUserDir(),"ana","xml",ChopCondInfo_xml)
    #20151202 end

    #CIpath=os.path.join(os.environ["UTSUSEMI_USR_DIR"],"ana","xml",CaseInfo_xml)
    CIpath=os.path.join(mu.UtsusemiEnvGetBaseDir(),spectcode,"ana","xml",CaseInfo_xml)

    print(CommentHead+"WiringInfo path           =",WIpath)
    print(CommentHead+"DetectorInfo path         =",DCpath)
    print(CommentHead+"CaseInfo path             =",CIpath)
    print(CommentHead+"ChopperConditionInfo path =",CCpath)

    if useTrignet==4 or useTrignet==5 or useTrignet==6:
        ## not use trignet use fast chopper -start

        evt.LoadParamFiles( WIpath, DCpath )
        evt.LoadChopCondFile( WIpath, DCpath,CCpath )
        evt.SetFilterHSChopperMode()
        evt.SetHistAllocation()

        if (starttime<0.0) and (endtime<0.0):
            pass
        else:
            evt.SetRangeOfSingleTimeSlicing(starttime,endtime)

        evt.LoadEventDataFiles( runnumber, datapath, t0datapath )
        DAT=mm.ElementContainerMatrix()
        evt.SetElementContainerMatrix( DAT, 1 )
        ## not use trignet use fast chopper -end
    elif useTrignet==1 or useTrignet==2 or useTrignet==3:
        ## use trignet -start

        evt.LoadParamFiles( WIpath, DCpath, CIpath )
        evt.LoadChopCondFile( WIpath, DCpath,CCpath )

        #evt.LoadTrignetChopFile( runnumber, "/data/DNA", t0datapath )
        evt.LoadTrignetChopFile( runnumber, datapath, t0datapath )
        evt.LoadTrignetEventFile( runnumber, datapath, t0datapath )
        evt.SetHistAllocation()

        if (starttime<0.0) and (endtime<0.0):
            pass
        else:
            evt.SetRangeOfSingleTimeSlicing(starttime,endtime)

        evt.LoadEventDataFiles( runnumber, datapath, t0datapath )
        DAT=mm.ElementContainerMatrix()
        evt.SetElementContainerMatrix( DAT, 1 )
        ## use trignet -end
    else:
        ## original not use trignet -start
        evt.LoadParamFiles( WIpath, DCpath )
        ##[inamura 180911]-->
        lambda_info_list = ChopCondInfo_xml.split(",")
        evt.SetLambdaParam(float(lambda_info_list[0]), float(lambda_info_list[1]))
        print(("## [inamura 180911] EventDataToEcm >> lambda params = ",float(lambda_info_list[0]), float(lambda_info_list[1])))
        ##<--[inamura 180911]
        evt.SetHistAllocation()

        if (starttime<0.0) and (endtime<0.0):
            pass
        else:
            evt.SetRangeOfSingleTimeSlicing(starttime,endtime)

        DAT = mm.ElementContainerMatrix()
        evt.SetElementContainerMatrix( DAT, runnumber, datapath, t0datapath )
        ## original not use trignet -end



    ##[inamura 180925]-->
    if mu.UTSUSEMIMANYOVERSION>'0.3.6':
        #URI=mu.UtsusemiReductionInEla(DAT)
        #URI.CalcPhi(Def_Pixel_Size[0],Def_Pixel_Size[1],Def_Pixel_Size[2])
        #del URI
        pass
    else:
        Phi=mu.PhiCalculation(DAT,Def_Pixel_Size[0],Def_Pixel_Size[1],Def_Pixel_Size[2])
        Phi.CalcPhi()
        del Phi
    ##<--[inamura 180925]
    
    ##[inamura 160227]-->
    import math
    for i in range( DAT.PutSize() ):
        for j in range( DAT(i).PutSize() ):
            hh = DAT(i,j).PutHeaderPointer()
            if (hh.CheckKey("PolarAngle")==1):
                pol_DNA = hh.PutDouble("PolarAngle")
                azm_DNA = hh.PutDouble("AzimAngle")
                ##[inamura 180925]-->
                if mu.UTSUSEMIMANYOVERSION>'0.3.6':
                    pol_v = mm.MakeDoubleVector(2)
                    pol_v[1]=0.0
                    azm_v = mm.MakeDoubleVector(2)
                    azm_v[1]=0.0
                else:
                    pol_v = hh.PutDoubleVector("PixelPolarAngle")
                    azm_v = hh.PutDoubleVector("PixelAzimAngle")
                    hh.Erase("PixelPolarAngle")
                    hh.Erase("PixelAzimAngle")

                pol_v[0] = pol_DNA/math.pi*180.0  # [rad]->[degree]
                azm_v[0] = azm_DNA/math.pi*180.0  # [rad]->[degree]
                ##<--[inamura 180925]

                hh.Add("PixelPolarAngle", pol_v )
                hh.Add("PixelAzimAngle", azm_v )

            if not isHistogram: ##[inamura 170616]
                hh.Add("isHistogram",0)
                
        if not isHistogram: ##[inamura 170616]
            hh_eca = DAT(i).PutHeaderPointer()
            hh_eca.Add("isHistogram",0)
    
    if not isHistogram: ##[inamura 170616]
        hh_ecm = DAT.PutHeaderPointer()
        hh_ecm.Add("isHistogram",0)
        
    ##<--[inamura 160227]

    del evt

    return DAT




import os
XXX="VNR"

def GetDataDir(addXXX=False):
    try:
        basepath=os.path.join(os.sep,"data")
    except:
        basepath=""

    if not os.path.exists( basepath ):
        try:
            basepath=os.path.join( os.environ["UTSUSEMI_DATA_DIR"] )
        except:
            raise UserWarning("Data Path is not found")

    if addXXX:
        basepath = os.path.join( basepath, XXX )
    
    return basepath

def GetUserDir():
    try:
        ret = os.path.join(os.sep,"usr","local","mlf",XXX)
    except:
        ret=""
    
    if not os.path.exists( ret ):
        if "UTSUSEMI_USR_DIR" in os.environ:
            ret = os.environ["UTSUSEMI_USR_DIR"]
        else:
            ret = ""
    if ret=="":
        raise UserWarning("UserDir is not found.")

    return ret
    
def GetInstCode():
    try:
        InstCode = XXX
    except:
        if "UTSUSEMI_INST_CODE" in os.environ:
            InstCode = os.environ["UTSUSEMI_INST_CODE"]
        else:
            InstCode = ""

    if InstCode=="":
        raise UserWarning("InstCode is not set")

    return InstCode
